%ENTRELAZADO DE TRAMA.
%function tr=enttrama(tt,n)
%Entradas:
%tt:ráfaga de 114 bits.
%n:número de la ráfaga dentro de la trama.
%Salidas:
%tr:ráfaga entrelazada.
function tr=enttrama(tt,n)
for i=57*(n-1):57*n-1
   if(mod(i,8)<=3)
      j=2*mod(49*i,57);
      tr(j+1)=tt(i+58-57*n);
   else
      j=2*mod(49*i,57)+1;
      tr(j+1)=tt(i+58-57*n);
   end
end
for i=57*(n+3):57*(n+4)-1
   if(mod(i,8)<=3)
      j=2*mod(49*i,57);
      tr(j+1)=tt(i-113-57*n);
   else
      j=2*mod(49*i,57)+1;
      tr(j+1)=tt(i-113-57*n);
   end
end